<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://orionorigin.com
 * @since      1.0.0
 *
 * @package    Vpc_Lns
 * @subpackage Vpc_Lns/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Vpc_Lns
 * @subpackage Vpc_Lns/admin
 * @author     ORION <support@orionorigin.com>
 */
class Vpc_Lns_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Lns_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Lns_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Lns_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Lns_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	}

	/**
	 * Runs the new version check and upgrade process
	 *
	 * @return \Vpc_Lns_Updater
	 */
	public function get_updater() {
		if ( class_exists( 'vpc' ) ) {
			do_action( 'vpc_before_init_updater' );
			require_once VPC_LNS_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-lns-updater.php';
			$updater = new Vpc_Lns_Updater();
			$updater->init();
			require_once VPC_LNS_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-lns-updating-manager.php';
			$updater->set_update_manager( new Vpc_Lns_Updating_Manager( VPC_LNS_VERSION, $updater->version_url(), VPC_LNS_MAIN_FILE ) );
			do_action( 'vpc_after_init_updater' );
			return $updater;
		}
	}

	/**
	 * Add Lom nava skin.
	 *
	 * @param array $skins The default skins array.
	 * @return type array
	 */
	public function vpc_custom_skin( $skins ) {
		$skins['VPC_Ln_Left_Sidebar_Skin']  = 'Lom-Nava Left Sidebar';
		$skins['VPC_Ln_Right_Sidebar_Skin'] = 'Lom-Nava Right Sidebar';
		return $skins;
	}

	/**
	 * Add skin global settings.
	 *
	 * @param array $global_settings The global settings.
	 * @return type
	 */
	public function add_global_settings( $global_settings ) {
		$begin = array(
			'type'  => 'sectionbegin',
			'id'    => 'vpc-lns-container',
			'table' => 'options',
		);

		$end = array( 'type' => 'sectionend' );

		$license_key     = array(
			'title'   => __( 'Lom nava skin license key', 'vpc-lns' ),
			'name'    => 'vpc-options[purchase-code-lom-nava-skin]',
			'type'    => 'text',
			'desc'    => __( 'This is the license key you received after your purchase.<a href=“https://orionorigin.com/guide/how-to-add-my-license/” target=“_blank”>Learn more</a>. <a href=“https://This is the license key you received after your purchase.<a href=“https://orionorigin.com/guide/how-to-add-my-license/” target=“_blank”>Learn more</a>. <a href=“https://orionorigin.com/my-account/orders/“ target=“blank”>Where can I find my license key</a>?.com/my-account/orders/“ target=“blank”>Where can I find my license key</a>?', 'vpc' ),
			'default' => '',
		);
		$lns_icon_width  = array(
			'title'   => __( 'Lom nava skin icon width', 'vpc-lns' ),
			'name'    => 'vpc-options[lns-icon-width]',
			'type'    => 'number',
			'default' => 70,
		);
		$lns_icon_height = array(
			'title'   => __( 'Lom nava skin icon height', 'vpc-lns' ),
			'name'    => 'vpc-options[lns-icon-height]',
			'type'    => 'number',
			'default' => 70,
		);
		$lns_icons_size  = array(
			'title'   => __( 'Lom nava skin icons size', 'vpc-lns' ),
			'name'    => 'vpc-options[lns-icons-size]',
			'type'    => 'groupedfields',
			'fields'  => array( $lns_icon_width, $lns_icon_height ),
			'default' => '',
			'desc'    => __( 'Set Lom nava skin icons size.', 'vpc-lns' ),
		);

		array_push( $global_settings, $begin );
		array_push( $global_settings, $license_key );
		array_push( $global_settings, $lns_icons_size );
		array_push( $global_settings, $end );
		return $global_settings;
	}

}
