<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://orionorigin.com
 * @since      1.0.0
 *
 * @package    Vpc_Lns
 * @subpackage Vpc_Lns/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Vpc_Lns
 * @subpackage Vpc_Lns/public
 * @author     ORION <support@orionorigin.com>
 */
class Vpc_Lns_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Lns_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Lns_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( 'bxslider-style', plugin_dir_url( __FILE__ ) . 'libs/bxslider/jquery.bxslider.min.css', array(), VPC_LNS_VERSION, 'all' );
		wp_enqueue_style( 'vpc-lns-public-css', plugin_dir_url( __FILE__ ) . 'css/vpc-lns-public.css', array(), VPC_LNS_VERSION, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Lns_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Lns_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script( 'bxslider-script', plugin_dir_url( __FILE__ ) . 'libs/bxslider/jquery.bxslider.min.js', array( 'jquery' ), VPC_LNS_VERSION, false );
		wp_enqueue_script( 'vpc-lns-public-js', plugin_dir_url( __FILE__ ) . 'js/vpc-lns-public.js', array( 'jquery' ), VPC_LNS_VERSION, false );
	}

}
